@@ -3,7 +3,7 @@
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
+ * Free Software Foundation; either version 3 of the License, or (at your
  * option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
@@ -68,7 +68,8 @@ gucharmap_get_unicode_name (gunichar wc)
   if ((wc >= 0x3400 && wc <= 0x4DB5)
       || (wc >= 0x4e00 && wc <= 0x9fcb)
       || (wc >= 0x20000 && wc <= 0x2A6D6)
-      || (wc >= 0x2a700 && wc <= 0x2b734))
+      || (wc >= 0x2a700 && wc <= 0x2b734)
+      || (wc >= 0x2b740 && wc <= 0x2b81d))
     {
       g_snprintf (buf, sizeof (buf), "CJK UNIFIED IDEOGRAPH-%04X", wc);
       return buf;
